<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="COCT_MT000003NL">
    <title>A_MedicalCondition</title>
        
        <rule context="hl7:subject/hl7:Condition">
            <assert role="error" test="not(@classCode) or @classCode='COND'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#COND"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'COND' zijn</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
                >COCT_MT000003NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
        </rule>
        
        <rule context="hl7:subject/hl7:Condition/hl7:id">
            <extends rule="II"/>
            
            <assert role="error" test="@root and @extension"
                >COCT_MT000003NL: id mist root of extension</assert>
            <assert role="error" test="substring(@root,1,20)='2.16.528.1.1007.3.3.'"
                >COCT_MT000003NL: root OID van Condition/id is niet gebaseerd op URA</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:code">
            <extends rule="CV"/>
            <assert role="warning" test="@code='DX' or @code='DERDX' or @code='OINT'"
                >COCT_MT000003NL: Condition/code moet DX, DERDX, OINT of specialisaties van OINT zijn</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.5.4'"
                >COCT_MT000003NL: Condition/code moet komen uit codesysteem '2.16.1.113883.5.4'</assert>
            
            <assert role="error" test="not(code='DX') or @codeSystem='2.16.840.1.113883.2.4.4.1.902.40'"
                >COCT_MT000003NL: contra-indicatie moet komen uit thesaurus tabel 40</assert>
            <assert role="error" test="not(@code='DINT') or ../hl7:value/@nullFlavor='OTH'"
                >COCT_MT000003NL: bij medicatie-intoleranties moet nullflavor = 'OTH' staan in Condition/value</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:text">
            <extends rule="ST"/>
        </rule>
        
        <rule context="hl7:subject/hl7:Condition/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='completed'"
                >COCT_MT000003NL: statusCode Condition moet active of completed zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:confidentialityCode">
            <extends rule="CV"/>
            <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.25'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Confidentiality.htm"
                >COCT_MT000003NL: vertrouwelijkheidscode moet komen uit codesysteem '2.16.840.1.113883.5.25'</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:uncertaintyCode">
            <extends rule="CV"/>
            <assert role="error" test="@code='U' or @code='N'"
                >COCT_MT000003NL :Condition/uncertaintyCode moet U of N zijn</assert>
            <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1053'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActUncertainty.htm"
                >COCT_MT000003NL: onzekerheidscode moet komen uit codesysteem '2.16.840.1.113883.5.1053'</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:value">
            <extends rule="CE"/>
        </rule>

    

    
    <!-- causativeAgent -->

        <title>causativeAgent</title>
        <rule context="hl7:subject/hl7:Condition/hl7:causativeAgent">
            <assert role="error" test="not(@typeCode) or @typeCode='CAGNT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#CAGNT"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'CAGNT' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:causativeAgent/hl7:administerableMaterial">
            <assert role="error" test="not(@classCode) or @typeCode='ADMM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ADMM"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'ADMM' zijn</assert>
        </rule>

    
    <!-- administerableMaterialKind -->

        <title>administerableMaterialKind</title>
        <rule context="hl7:subject/hl7:Condition/hl7:causativeAgent/hl7:administerableMaterial/hl7:administerableMaterialKind">
            <assert role="error" test="not(@classCode) or @classCode='MAT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#MAT"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'ADMM' zijn</assert>
            <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityDeterminer.htm#KIND"
                >COCT_MT000003NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:causativeAgent/hl7:administerableMaterial/hl7:administerableMaterialKind/hl7:code">
            <extends rule="CE"/>
            <assert role="error" test="@code"
                >COCT_MT000003NL: een geldige stof(groep) is verplicht</assert>
            <assert role="error"
                test="@codeSystem='2.16.840.1.113883.2.4.4.1.902.122' or @codeSystem='2.16.840.1.113883.2.4.4.1.750' or @codeSystem='2.16.840.1.113883.2.4.4.1.725'"
                >COCT_MT000003NL: stof(groep) moet komen uit thesaurus tabel 122 (ongewenste groep), SNK of SSK</assert>
        </rule>
    

    
    <!-- author -->
        <title>author</title>
        <rule context="hl7:subject/hl7:Condition/hl7:author">
            <assert role="error" test="not(@typeCode) or @typeCode='AUT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#AUT"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'AUT' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:author/hl7:patient">
            <assert role="error" test="not(@classCode) or @classCode='PAT'"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'PAT' zijn</assert>
        </rule>
    

    <!-- informant -->
        <title>informant</title>
        <rule context="hl7:subject/hl7:Condition/hl7:informant">
            <assert role="error" test="not(@typeCode) or @typeCode='INF'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#INF"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'INF' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:informant/hl7:patient">
            <assert role="error" test="not(@classCode) or @classCode='PAT'"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'PAT' zijn</assert>
        </rule>
  
    <!-- support -->
        <rule context="hl7:subject/hl7:Condition/hl7:support">
            <assert role="error" test="not(.)"
                >COCT_MT000003NL: support: voorlopig wordt dit deel van het model nog niet gebruikt</assert>
        </rule>

    <!-- 
        subjectOf1 
    -->
        <title>subjectOf1</title>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf1">
            <assert role="error" test="not(@typeCode) or @typeCode='SUBJ'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SUBJ"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'SUBJ' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf1/hl7:severityObservation">
            <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#OBS"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'OBS' zijn</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
                >COCT_MT000003NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf1/hl7:severityObservation/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="@code='SEV'">COCT_MT000003NL: @code moet SEV</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.5.4'"
                >COCT_MT000003NL: ernst van de conditie moet komen uit codesysteem '2.16.840.1.113883.5.4'</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf1/hl7:severityObservation/hl7:statusCode">
            <extends rule="CS"/>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf1/hl7:severityObservation/hl7:value">
            <extends rule="CE"/>
            <assert role="error" test="@code='MILD' or @code='MOD' or @code='SEV'"
                >COCT_MT000003NL: ongeldige waarde voor severityObservation.value (MILD, MOD of SEV)</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.15.20'"
                >COCT_MT000003NL: OID moet overeenkomen met codesysteem voor severityObservation/value</assert>
        </rule>
    
    <!-- 
        subjectOf2 
    -->
        <title>subjectOf2</title>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf2">
            <assert role="error" test="not(@typeCode) or @typeCode='SUBJ'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SUBJ"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'SUBJ' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf2/hl7:annotation">
            <assert role="error" test="not(@classCode) or @classCode='ACT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#ACT"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'ACT' zijn</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
                >COCT_MT000003NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf2/hl7:annotation/hl7:text">
            <extends rule="ST"/>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf2/hl7:annotation/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='completed'"
                >COCT_MT000003NL: statusCode/@code moet 'completed' zijn</assert>
        </rule>
    
    <!-- 
        annotation/author
    -->
        <title>annotation/author</title>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf2/hl7:annoation/hl7:author">
            <assert role="error" test="not(@typeCode) or @typeCode='AUT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#AUT"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'AUT' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf2/hl7:annotation/hl7:author/hl7:time">
            <extends rule="TS"/>
        </rule>

    <!-- 
        subjectOf4 
    -->
        <rule context="hl7:subject/hl7:Condition/hl7:subjectOf4">
            <assert role="error" test="not(.)"
                >COCT_MT000003NL: subjectOf4: voorlopig wordt dit deel van het model nog niet gebruikt</assert>
        </rule>
    
    <!-- 
        predecessor
    -->
        <title>predecessor</title>
        <rule context="hl7:subject/hl7:Condition/hl7:predecessor">
            <assert role="error" test="not(@typeCode) or @typeCode='SUCC'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SUCC"
                >COCT_MT000003NL: @typeCode moet indien aanwezig 'SUCC' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:predecessor/hl7:conditionReference">
            <assert role="error" test="not(@classCode) or @classCode='COND'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#COND"
                >COCT_MT000003NL: @classCode moet indien aanwezig 'COND' zijn</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
                >COCT_MT000003NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Condition/hl7:predecessor/hl7:conditionReference/hl7:id">
            <extends rule="II"/>
            
            <assert role="error" test="@root and @extension"
                >COCT_MT000003NL: id mist root of extension</assert>
            <assert role="error" test="substring(@root,1,20)='2.16.528.1.1007.3.3.'"
                >COCT_MT000003NL: root OID van Condition/id is niet gebaseerd op URA</assert>
        </rule>
    </pattern>
