<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="COCT_MT924000NL">
    <title>A_MedicationDispenseEvent universal</title>
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='SPLY'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SPLY"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'SPLY' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >COCT_MT924000NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
    </rule>
    
    <rule context="$element/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root and @extension"
            >COCT_MT924000NL: id moet een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:code">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:text">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@code='completed'"
            >COCT_MT924000NL: statusCode/@code moet 'completed' zijn</assert>
    </rule>
    <rule context="$element/hl7:effectiveTime">
        <extends rule="IVL_TS"/>
        <assert role="error" test="not(hl7:width or hl7:center)"
            >COCT_MT924000NL: effectiveTime/width en effectiveTime/center niet gebruiken</assert>
        <assert role="error" test="@value or (not(@value) and hl7:low/@value)"
            >COCT_MT924000NL: effectiveTime/@value of effectiveTime/low moet een waarde hebben</assert>
        <assert role="error" test="not(@value) or matches(@value,'[0-9]{8}')"
            >COCT_MT924000NL: effectiveTime/@value moet minimaal tot op de dag worden opgegeven</assert>
        <assert role="error" test="not(hl7:low/@value) or matches(hl7:low/@value,'[0-9]{12}')"
            >COCT_MT924000NL: effectiveTime/low/@value moet minimaal tot op de minuut worden opgegeven</assert>
        <assert role="error" test="not(hl7:high/@value) or matches(hl7:high/@value,'[0-9]{12}')"
            >COCT_MT924000NL: effectiveTime/high/@value moet minimaal tot op de minuut worden opgegeven</assert>
    </rule>
    <rule context="$element/hl7:quantity">
        <extends rule="PQ"/>
        <assert role="error" test="@nullFlavor='NA' or @value &gt; 0"
            >COCT_MT924000NL: quantity moet groter zijn dan 0 of @nullFlavor moet "NA" zijn</assert>
        <assert role="error" test="@nullFlavor='NA' or 
            (count(hl7:translation)=1 and hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2']) or 
            (count(hl7:translation)=2 and hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2'] and hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.12'])"
            >COCT_MT924000NL: quantity moet een vertaling hebben naar G-Standaard basiseenheden tabel 2 en mag ook een vertaling hebben naar G-Standaard deelverpakkingen tabel 4</assert>
        <assert role="error" test="not(hl7:translation) or hl7:translation[@code and @displayName]"
            >COCT_MT924000NL: quantity in translation moeten een waarde in @displayName hebben bij @code</assert>
    </rule>
    <rule context="$element/hl7:expectedUseTime">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- 
        destination
    -->
    <rule context="$element/hl7:destination">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- 
        performer
    -->
    <rule context="$element/hl7:performer">
        <assert role="error" test="not(@typeCode) or @typeCode='PRF'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#PRF"
            >COCT_MT924000NL: @typeCode moet indien aanwezig 'PRF' zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ASSIGNED"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@nullFlavor='MSK'"
            >COCT_MT924000NL: identificatie van de verstrekker moet worden gemaskeerd</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:representedOrganization">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- 
        product
    -->
    <rule context="$element/hl7:product">
        <assert role="error" test="not(@typeCode) or @typeCode='PRD'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#PRD"
            >COCT_MT924000NL: @typeCode moet indien aanwezig 'PRD' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:substitutionCode">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication">
        <assert role="error" test="not(@classCode) or @classCode='DST'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#DST"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'DST' zijn</assert>
    </rule>
    
    <!-- E_MedicationKind universal controleren op interactieniveau -->
    
    <!-- 
        directTargetOf
    -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf">
        <assert role="error" test="not(@typeCode) or @typeCode='TPA' or @typeCode='DIR'"
            >COCT_MT924000NL: @typeCode moet indien aanwezig 'TPA' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription">
        <assert role="error" test="not(@classCode) or @classCode='SBADM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'SBADM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT924000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@nullFlavor='UNK' or (@root and @extension)"
            >COCT_MT924000NL: id moet een waarde hebben of @nullFlavor='UNK'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:text">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:statusCode">
        <extends rule="CS"/>
        <assert test="@nullFlavor='UNK' or @code='active' or @code='completed'"
            >COCT_MT924000NL: <value-of select="local-name(.)"/>/@code moet 'active' of 'completed' zijn, of @nullFlavor='UNK'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:confidentialityCode">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- subject -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject">
        <assert role="error" test="not(@typeCode) or @typeCode='SBJ'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#SBJ"
            >COCT_MT924000NL: @typeCode moet indien aanwezig 'SBJ' zijn</assert>
    </rule>
    <title>COCT_MT050000NL R_PatientNL universal</title>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient">
        <assert role="error" test="not(@classCode) or @classCode='PAT'"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'PAT' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.840.1.113883.2.4.6.3'"
            >COCT_MT924000NL: patiënten moeten een burgerservicenummer hebben</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:addr">
        <extends rule="AD"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:telecom">
        <extends rule="TEL"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:statusCode">
        <extends rule="CS"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person">
        <assert role="error" test="hl7:name/hl7:family"
            >COCT_MT924000NL: tenminste een patiëntachternaam moet een waarde hebben</assert>
        <assert role="error" test="hl7:birthTime"
            >COCT_MT924000NL: birthTime moet een waarde hebben</assert>
        <assert role="error" test="hl7:administrativeGenderCode"
            >COCT_MT924000NL: administrativeGenderCode moet een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.840.1.113883.2.4.6.3'"
            >COCT_MT924000NL: als er een persoonsnummer wordt gebruikt moet dat het burgerservicenummer zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:name">
        <extends rule="PN"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/AdministrativeGender.htm"
            >COCT_MT924000NL: geslacht moet komen uit codesysteem '2.16.840.1.113883.5.1'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:birthTime">
        <extends rule="TS"/>
    </rule>
    
    <!-- author -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author">
        <assert role="error" test="not(@typeCode) or @typeCode='AUT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#AUT"
            >COCT_MT924000NL: @typeCode moet indien aanwezig 'AUT' zijn</assert>
        <assert role="error" test="hl7:time"
            >COCT_MT924000NL: moment van voorschrijven is verplicht</assert>
        
        <let name="pharmaGp" value="'01.004'"/>
        <let name="roleCodeNL" value="'2.16.840.1.113883.2.4.15.111'"/>
        <let name="reponsibleRoot" value="../../../../../hl7:responsibleParty/hl7:assignedCareProvider/hl7:id/@root"/>
        <let name="reponsibleExt"  value="../../../../../hl7:responsibleParty/hl7:assignedCareProvider/hl7:id/@extension"/>
        <let name="reponsibleCode" value="../../../../../hl7:responsibleParty/hl7:assignedCareProvider/hl7:code[@codeSystem=$roleCodeNL]/@code"/>
        <assert role="error" test="not(hl7:AssignedPerson/hl7:id[@root=$reponsibleRoot and @extension=$reponsibleExt]) or
            hl7:AssignedPerson/hl7:code[@code=$pharmaGp and codeSystem=$roleCodeNL] or
            $reponsibleCode=$pharmaGp"
            >COCT_MT924000NL: medicationDispenseEvent/responsibleParty en presciption/author zijn gelijk. Alleen een apotheekhoudend huisarts mag zowel voorschrijven als afleveren.</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:time">
        <extends rule="TS"/>
        <let name="tsValue" value="@value"/>
        <let name="normTsValue" value="xs:integer(substring(concat(replace($tsValue,'[^\d]',''),'00000000000000'),1,14))"/>
        
        <let name="creationTime" value="ancestor::hl7:*[hl7:creationTime][1]/hl7:creationTime/@value"/>
        <let name="normCreationTime" value="xs:integer(substring(concat(replace($creationTime,'[^\d]',''),'00000000000000'),1,14))"/>
        
        <assert test="@nullFlavor='UNK' or string-length($tsValue)=8 or string-length($tsValue)=12"
            >COCT_MT924000NL: moment van voorschrijven moet indien aanwezig tot op de dag of tot op de minuut zijn</assert>
        
        <assert role="error"
            test="not(@value) or $normTsValue &lt;= $normCreationTime"
            >COCT_MT924000NL: moment van voorschrijven '<value-of select="$tsValue"/>' moet liggen vóór
            het moment van verzenden van het bericht '<value-of select="$creationTime"/>'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:modeCode">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:signatureCode">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:signatureText">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- assignedPerson -->
    <title>COCT_MT090101 R_AssignedPerson identified</title>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:AssignedPerson" subject="COCT_MT090101">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:AssignedPerson/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.1'"
            >COCT_MT924000NL: identificatie van de voorschrijver moet UZI of AGB zijn</assert>
    </rule>
    
    <!-- reason -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- reference -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reference">
        <assert role="error" test="not(.)"
            >COCT_MT924000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    
    <!-- therapeuticAgentOf -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf">
        <assert role="error" test="not(@typeCode) or @typeCode='TPA'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#TPA"
            >COCT_MT940000NL: @typeCode moet indien aanwezig 'TPA' zijn</assert>
    </rule>
    
    <!-- COCT_MT940000NL -->
    
    <!-- responsibleParty -->
    <rule context="$element/hl7:responsibleParty">
        <assert role="error" test="not(@typeCode) or @typeCode='RESP'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#RESP"
            >COCT_MT924000NL: @typeCode moet indien aanwezig 'RESP' zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ASSIGNED"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.1'"
            >COCT_MT924000NL: identificatie van de verantwoordelijke zorgverlener moet UZI zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="@nullFlavor='UNK' or (@codeSystem='2.16.840.1.113883.2.4.15.111' and (@code='01.004' or @code='17.000' or @code='17.060') and @displayName)"
            >COCT_MT924000NL: rolcode van de verantwoordelijke zorgverlener moet komen uit '2.16.840.1.113883.2.4.15.111', één van 01.004, 17.000, of 17.060 zijn, en een weergavenaam hebben</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization">
        <assert role="error" test="not(@classCode) or @classCode='ORG'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ORG"
            >COCT_MT924000NL: @classCode moet indien aanwezig 'ORG' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='INSTANCE'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityDeterminer.htm#INSTANCE"
            >COCT_MT924000NL: @determinerCode moet indien aanwezig 'INSTANCE' zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.3'"
            >COCT_MT924000NL: identificatie van de organisatie van de verantwoordelijke zorgverlener moet URA zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:name">
        <extends rule="ON"/>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:addr">
        <extends rule="AD"/>
        <assert role="error" test="@use='WP' and hl7:city"
            >COCT_MT924000NL: @use moet 'WP' zijn en de vestigingsplaats moet een waarde hebben</assert>
    </rule>
    
</pattern>
