<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van REPC_IN990005NL - Primary Care Locum Report</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>
    
    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>
    
    <!--pattern is-a="attentionLine" id="REPC_IN990005NL-attentionLine">
        <param name="messagePatientId" value="hl7:ControlActProcess/hl7:subject/hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"/>
        <param name="attentionLineOptional" value="'true'"/>
    </pattern-->
        
    <pattern is-a="transmission-wrapper" id="REPC_IN990005NL-wrapper">
        <param name="element" value="hl7:REPC_IN990005NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="REPC_IN990005NL-controlAct">
        <param name="element" value="hl7:REPC_IN990005NL/hl7:ControlActProcess"/>
    </pattern>
    
    <pattern>
        <!-- profileId -->
        <rule context="hl7:REPC_IN990005NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:REPC_IN990005NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='AL'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'AL'.</assert>
        </rule>
        <rule context="hl7:REPC_IN990005NL/hl7:attentionLine">
            <assert role="warning" test="not(.)">Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
    </pattern>
    
    <!-- ControlAct Wrapper -->
    <pattern>
        <title>ControlAct Wrapper</title>
        <rule context="hl7:ControlActProcess">
            <assert role="error" test="@moodCode='EVN'">moodCode is niet gelijk aan EVN</assert>
            <assert role="error" test="hl7:authorOrPerformer/@typeCode='AUT'">typecode
                authorOrPerformer is niet gelijk aan AUT</assert>
            <assert role="error"
                test="hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:id/@root='2.16.528.1.1007.3.1'"
                >OID root van AssignedPerson/Id wijst niet naar UZI register personen</assert>
            <assert role="error"
                test="hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@root='2.16.528.1.1007.3.3'"
                >OID root van Organization/Id wijst niet naar UZI register instellingen</assert>
        </rule>
    </pattern>
    <!-- Patient en Arts -->
    <pattern>
        <title>Patientgegevens</title>
        <rule context="hl7:PrimaryCareProvision/hl7:subject">
            <assert role="error" test="@contextControlCode='AP'">De contextControlCode is niet
                gelijk aan AP</assert>
            <assert role="error" test="hl7:Patient/hl7:statusCode/@code='active' or
                hl7:Patient/hl7:statusCode/@code='terminated'">statusCode is niet
                gelijk aan active of terminated</assert>
            <assert role="error"
                test="count(hl7:Patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3'
                and @extension])>0 or @nullFlavor">BSN ontbreekt in Patient</assert>
            <assert role="error" test="hl7:Patient/hl7:Person/hl7:birthTime/@value">Geboortedatum
            ontbreekt</assert>
        </rule>
    </pattern>
    <!-- PrimaryCareProvision Act -->
    <pattern>
        <title>PrimaryCareProvision Act</title>
        <rule context="hl7:PrimaryCareProvision">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension</assert>
            <assert role="error" test="hl7:statusCode/@code='completed'">statusCode is niet gelijk aan completed</assert>
            <assert role="error" test="hl7:effectiveTime/hl7:low/@value">Startdatum is niet aangegeven</assert>
            <assert role="error" test="not(hl7:statusCode/@code='completed') or
                (hl7:statusCode/@code='completed' and
                hl7:effectiveTime/hl7:high/@value)">statusCode is 'completed', maar de einddatum
                ontbreekt</assert>
            <assert role="error" test="not(hl7:statusCode/@code='active') or
                (hl7:statusCode/@code='active' and
                not(hl7:effectiveTime/hl7:high/@value))">statusCode is 'active' terwijl de
                einddatum aanwezig is</assert>
        </rule>
    </pattern>
    <!-- Acts direct gekoppeld aan PrimaryCareProvision -->
    <pattern>
        <title>Episodes, EpisodeOfCondition deel</title>
        <rule context="hl7:episodeOfCondition">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension</assert>
            <assert role="error" test="string-length(hl7:text)>0">Episode bevat geen tekst</assert>
            <assert role="error" test="hl7:statusCode/@code='active' or
                hl7:statusCode/@code='completed'">statusCode is niet gelijk aan
                active of completed</assert>
            <assert role="error" test="hl7:effectiveTime/hl7:low/@value">Startdatum is niet aangegeven</assert>
            <assert role="error" test="not(hl7:statusCode/@code='completed') or
                (hl7:statusCode/@code='completed' and
                hl7:effectiveTime/hl7:high/@value)">statusCode is 'completed', maar de einddatum
                ontbreekt</assert>
            <assert role="error" test="not(hl7:statusCode/@code='active') or
                (hl7:statusCode/@code='active' and
                not(hl7:effectiveTime/hl7:high/@value))">statusCode is 'active' terwijl de
                einddatum aanwezig is</assert>
            <assert role="error" test="not(hl7:reason) or
                hl7:reason/@contextConductionInd='true'">Er is een diagnose, maar
                de contextConductionInd is niet gelijk aan 'true'</assert>
            <assert role="error" test="not(hl7:component2) or
                hl7:component2/@contextConductionInd='true'">Er is een
                EpisodOfCare, maar de contextConductionInd is niet gelijk aan 'true'</assert>
            <assert role="error" test="not(hl7:component1) or
                hl7:component1/@contextConductionInd='true'">Er is een
                EpisodeOfCondition, maar de contextConductionInd is niet gelijk aan 'true'</assert>
            <assert role="error" test="not(hl7:component1/hl7:episodeOfCondition/hl7:component1)">Episodes mogen
                slechts 1 niveau diep genest worden</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Episodes, EpisodeOfCare deel</title>
        <rule context="hl7:episodOfCare">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension</assert>
            <assert role="error" test="hl7:statusCode/@code='active' or
                hl7:statusCode/@code='completed'">statusCode is niet gelijk aan
                active of completed</assert>
            <assert role="error" test="hl7:effectiveTime/hl7:low/@value">Startdatum is niet aangegeven</assert>
            <assert role="error" test="not(hl7:statusCode/@code='completed') or
                (hl7:statusCode/@code='completed' and
                hl7:effectiveTime/hl7:high/@value)">statusCode is 'completed', maar de einddatum
                ontbreekt</assert>
            <assert role="error" test="not(hl7:statusCode/@code='active') or
                (hl7:statusCode/@code='active' and
                not(hl7:effectiveTime/hl7:high/@value))">statusCode is 'active' terwijl de
                einddatum aanwezig is</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Consulten</title>
        <rule context="hl7:encounter/hl7:id">
            <assert role="error" test="@root and @extension">Id element mist root of extension</assert>
        </rule>
        <rule context="hl7:encounter/hl7:effectiveTime">
            <assert role="error" test="hl7:low/@value">Startdatum is niet aangegeven</assert>
        </rule>
        <rule context="hl7:encounter/hl7:code">
            <assert role="error" test="@code or @nullFlavor='UNK' or @nullFlavor='OTH'">Er moet een code attrbituut zijn of een nullFlavor attribuut met de waarde 'UNK' of 'OTH'.</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.14' or @nullFlavor">De codesystem OID moet naar NHG tabel 14 wijzen of er moet een nullFlavor attribuut zijn.</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0 or @nullFlavor">Het displayName attribuut moet gevuld zijn of er moet een nullFlavor attribuut zijn.</assert>
        </rule>
    	<rule context="hl7:encounter/hl7:component">
    		<report role="warning" test="not(hl7:sequenceNumber)">Component bevat geen sequenceNumber</report>
    	</rule>
    </pattern>
    <pattern>
        <title>Attentieregels</title>
        <rule context="hl7:pertinentAnnotationObsEvent">
            <assert role="error" test="not(hl7:code) or hl7:code/@code='ATT' or
                hl7:code/@code='SOC' or hl7:code/@code='SOS' or
                hl7:code/@code='WNN'">code attribuut in code is niet gelijk aan
                ATT,SOC,SOS of WNN</assert>
            <assert role="error" test="string-length(hl7:text)>0">Attentieregel bevat geen tekst</assert>
            <assert role="error" test="hl7:author">Bij attentieregels in waarneemberichten is de auteur verplicht.</assert>
        </rule>
    </pattern>
    <!-- CMETs in Activities ChoiceBox -->
    <pattern>
        <title>Journaalregels</title>
        <rule context="hl7:JournalEntry">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension
                attribuut</assert>
            <assert role="error" test="hl7:code/@code='S' or hl7:code/@code='O'
                or hl7:code/@code='E' or
                hl7:code/@code='P'">code attribuut in code is niet S,O,E of P</assert>
            <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.32.2'">OID
                root wijst niet naar PriCa tabel SOEP aanduidingen</assert>
            <assert role="error" test="string-length(hl7:code/@displayName)>0">displayName attribuut in code is
                niet gevuld</assert>
            <assert role="error" test="ancestor::*[name()='encounter'] or hl7:effectiveTime/@value">de
                effectiveTime ontbreekt en de journaalregel is geen onderdeel van een consult</assert>
            <assert role="error" test="string-length(hl7:value)>0">Journaalregel bevat geen tekst</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Diagnoses</title>
        <rule context="hl7:ObservationDx">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension
                attribuut</assert>
            <assert role="error" test="hl7:code/@code='DISDX' or
                hl7:code/@code='ADMDX'">Het soort diagnose is niet DISDX of ADMDX</assert>
            <assert role="error" test="ancestor::*[name()='encounter' or name()='episodeOfCondition'] or
                hl7:effectiveTime/hl7:low/@value">de effectiveTime (startdatum) ontbreekt en de
                diagnose is geen onderdeel van een consult of episode</assert>
            <assert role="error" test="hl7:value and
                hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.31.1'">OID root wijst
                niet naar ICPC 1-2000NL</assert>
            <assert role="error" test="string-length(hl7:value/@code)>0">ICPC code ontbreekt in de value</assert>
            <assert role="error" test="string-length(hl7:value/@displayName)>0">DisplayName ontbreekt in de value</assert>
            <assert role="error" test="not(hl7:code/@code='ADMDX') or
                (hl7:code/@code='ADMDX' and
                hl7:author/hl7:Patient/hl7:id/@root and hl7:author/hl7:Patient/hl7:id/@extension)"
                >Diagnose code is 'ADMDX', maar de patient ontbreekt als auteur</assert>
            <assert role="error" test="not(hl7:code/@code='DISDX') or
                (hl7:code/@code='DISDX' and not(hl7:author/hl7:Patient))">Diagnose
                code is 'DISDX', maar er is een patient als auteur </assert>
        </rule>
    </pattern>
    <pattern>
        <title>Verwijzingen</title>
        <rule context="hl7:PatientCareProvisionRequest">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension
                attribuut</assert>
            <assert role="error" test="hl7:statusCode/@code and
                hl7:statusCode/@code='completed'">statusCode is niet gelijk aan
                completed</assert>
            <assert role="error" test="ancestor::*[name()='encounter'] or
                hl7:effectiveTime/hl7:low/@value">de effectiveTime (startdatum) ontbreekt en de
                verwijzing is geen onderdeel van een consult</assert>
            <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.30.12'">OID
                root wijst niet naar NHG tabel 12</assert>
            <assert role="error" test="string-length(hl7:code/@code)>0">code attribuut ontbreekt in de code</assert>
            <assert role="error" test="string-length(hl7:code/@displayName)>0">DisplayName attribuut ontbreekt in
                de code</assert>
            <assert role="error" test="hl7:performer/hl7:AssignedEntity/hl7:id/@root and
                hl7:performer/hl7:AssignedEntity/hl7:id/@extension">De performer is niet
                geidentificeerd</assert>
        </rule>
    </pattern>
    <pattern>
        <title>Therapie</title>
        <rule context="hl7:ProcedureEvent">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">Id element mist root of extension
                attribuut</assert>
            <assert role="error" test="hl7:statusCode/@code and
                hl7:statusCode/@code='completed'">statusCode is niet gelijk aan
                completed</assert>
            <assert role="error" test="ancestor::*[name()='encounter'] or
                hl7:effectiveTime/hl7:low/@value">de effectiveTime (startdatum) ontbreekt en de
                therapie is geen onderdeel van een consult</assert>
            <assert role="error" test="not(hl7:code) or
                hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.31.1'">OID root wijst
                niet naar een ICPC-1-2000NL code</assert>
            <assert role="error" test="not(hl7:code) or string-length(hl7:code/@code)>0">code attribuut ontbreekt
                in de code</assert>
            <assert role="error" test="not(hl7:code) or string-length(hl7:code/@displayName)>0">DisplayName
                attribuut ontbreekt in de code</assert>
        </rule>
    </pattern>
    <!-- Medicatievoorschriften -->
    <pattern>
        <title>Medicatievoorschriften</title>
        <rule context="hl7:Prescription">
            <assert role="error" test="hl7:author/hl7:time/@value">
                Datum voorschrift ontbreekt
            </assert>
        </rule>
    </pattern>
    <!-- Rest -->
    <pattern>
        <title>Gebruik G-Standaard codes</title>
        <rule context="hl7:MedicationKind/hl7:code">
            <assert role="error"
                test="@codeSystem='2.16.840.1.113883.2.4.4.1' or
                @codeSystem='2.16.840.1.113883.2.4.4.10' or
                @codeSystem='2.16.840.1.113883.2.4.4.7' or
                @codeSystem='2.16.840.1.113883.2.4.4.8' or @nullFlavor='OTH'"
                >codeSystem moet een GPK, HPK, PRK of ZI nummer zijn of er moet een nullFlavor=OTH zijn.</assert>
        </rule>
    </pattern>
</schema>
