<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Implementatiehandleiding HL7v3 Basiscomponenten, v2.2 - Datatype 1.0 AD - Address
    Status: in behandeling
-->
<rule abstract="true" id="AD" see="http://hl7book.net/index.php?title=DatatypesR1:AD" xmlns="http://purl.oclc.org/dsdl/schematron">
    <extends rule="ANY"/>
    
    <!-- Test op mixed content en lege adressen -->
    <assert role="error" test="(count(*)>0 and string-length(normalize-space(text()[1]))=0) or count(*)=0">Datatype AD: adres geheel in tekst of geheel in
        elementen (geen mixed content)</assert>
    <assert role="error" test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">Datatype AD: no useablePeriod if null</assert>
    <assert role="error" test="count(*[self::hl7:useablePeriod][@updateMode])=0"
        >Datatype AD: updateMode mag niet worden gebruikt op adreselementen</assert>
    
    <!-- Test formaat postcode -->
    <let name="postalCodeText" value="hl7:postalCode/text()"/>
    <let name="countryCode" value="hl7:country/@code"/>
    <let name="countryCodeSystem" value="hl7:country/@codeSystem"/>
    <let name="countryText" value="upper-case(normalize-space(hl7:country))"/>
    
    <assert role="error" test="if (@codeSystem='2.16.840.1.113883.2.4.4.15') then (
        matches(@code,'^[0-9]{4}[A-Z]{2}$')
        ) else ( 1=1 )"
        >Datatype AD: postcodes onder codeSystem '2.16.840.1.113883.2.4.4.15' moeten voldoen aan '9999AA'</assert>
    
    <assert role="error"
        test="if (hl7:postalCode/text() and (not(hl7:country) or 
        ($countryCode='NL' and ($countryCodeSystem='2.16.1' or $countryCodeSystem='1.3.6.1.4.1.1466.115.121.1.11' or $countryCodeSystem='1.0.3166.1.2.2')) or
        ($countryCode='NLD' and $countryCodeSystem='2.16.2') or
        ($countryCode='528' and $countryCodeSystem='2.16.3') or
        $countryText='NL' or
        $countryText='NLD' or
        $countryText='NEDERLAND'
        )) then ( matches($postalCodeText,'^[0-9]{4} [A-Z]{2}$')
        ) else ( 1=1 )"
        >Datatype AD: Nederlandse postcodes in de text-nodes moeten voldoen aan '9999 AA'</assert>
    
    <let name="illegalAddressPart"
        value="*[local-name(.)!='delimiter' and local-name(.)!='buildingNumberSuffix' and
        local-name(.)!='country' and local-name(.)!='county' and
        local-name(.)!='city' and local-name(.)!='postalCode' and
        local-name(.)!='houseNumber' and local-name(.)!='streetName' and
        local-name(.)!='additionalLocator'][1]/name()"/>
    <assert role="error" test="count(*)=0 or string-length($illegalAddressPart)=0">Datatype AD: binnen Nederland mogen alleen delimiter, country, county, 
        city, postalCode, houseNumber, buildingNumberSuffix, streetName en additionalLocator worden gebruikt. Gevonden '<value-of select="$illegalAddressPart"/>'.</assert>
    
    <assert role="error" test="count(*)=0 or count(*[not(self::hl7:postalCode) and not(self::hl7:country) and @code])=0">Datatype AD: alleen postalCode en country 
        kunnen gecodeerd worden. Gevonden '<value-of select="*[not(self::hl7:postalCode) and not(self::hl7:country) and @code][1]/name()"/>'</assert>
    
</rule>
